#
#   Pyrex - Command Line Parsing
#

import sys

usage = """\
Usage: pyrexc [options] sourcefile...
Options:
  -v, --version                  Display version number of pyrex compiler
  -l, --create-listing           Write error messages to a listing file
  -o, --output-file <filename>   Specify name of generated C file"""

def bad_usage():
  print >>sys.stderr, usage
  sys.exit(1)

def parse_command_line(args):
  from Main import CompilationOptions, default_options

  def pop_arg():
    if args:
      return args.pop(0)
    else:
      bad_usage()

  options = CompilationOptions(default_options)
  sources = []
  while args:
    if args[0][:1] == "-":
      option = pop_arg()
      #print "parse_command_line: examining option", repr(option) ###
      if option in ("-v", "--version"):
        options.show_version = 1
      elif option in ("-o", "--output-file"):
        options.output_file = pop_arg()
      elif option in ("-l", "--create-listing"):
        options.use_listing_file = 1
      else:
        bad_usage()
    else:
      #print "parse_command_line: collecting source file", repr(args[0]) ###
      sources.append(pop_arg())
  if options.use_listing_file and len(sources) > 1:
    print >>sys.stderr, \
      "pyrexc: Only one source file allowed when using -o"
    sys.exit(1)
  return options, sources
